import { fromObject } from "@nativescript/core/data/observable";
const eventName = "activityChanged";
export class RecognizerCallbackManager {
    constructor() {
        this.notificationCenter = fromObject({});
        this.listenerCounter = 0;
        this.callbacks = new Map();
    }
    add(callback) {
        const callbackId = this.listenerCounter;
        const internalCallback = (eventData) => callback(eventData.data);
        this.callbacks.set(callbackId, internalCallback);
        this.notificationCenter.on(eventName, internalCallback);
        return this.listenerCounter++;
    }
    notifyAll(activityChange) {
        if (!this.notificationCenter.hasListeners(eventName)) {
            return;
        }
        const eventData = {
            eventName,
            object: this.notificationCenter,
            data: Object.assign({}, activityChange),
        };
        this.notificationCenter.notify(eventData);
    }
    remove(callbackId) {
        if (!this.callbacks.has(callbackId)) {
            return;
        }
        const callback = this.callbacks.get(callbackId);
        this.notificationCenter.off(eventName, callback);
        this.callbacks.delete(callbackId);
    }
    removeAll() {
        this.notificationCenter.off(eventName);
        this.callbacks.clear();
    }
}
//# sourceMappingURL=callback-manager.js.map