import { Couchbase } from "nativescript-couchbase-plugin";
const DATABASE_NAME = "context-apis";
const DOC_TYPE = "recognizer-state";
class RecognizersStateStoreDb {
    constructor() {
        this.database = new Couchbase(DATABASE_NAME);
    }
    async isActive(recognizer) {
        const recognizerData = await this.getRecognizerData(recognizer);
        if (!recognizerData) {
            return false;
        }
        return recognizerData.active;
    }
    async getStartOptions(recognizer) {
        const isActive = await this.isActive(recognizer);
        if (!isActive) {
            return null;
        }
        const recognizerData = await this.getRecognizerData(recognizer);
        if (!recognizerData) {
            return null;
        }
        return recognizerData.startOptions;
    }
    async markAsActive(recognizer, startOptions) {
        await this.updateStatus(recognizer, true, startOptions);
    }
    async markAsInactive(recognizer) {
        await this.updateStatus(recognizer, false);
    }
    async getLastActivity(recognizer) {
        const recognizerData = this.database.getDocument(recognizer);
        if (!recognizerData) {
            return null;
        }
        const lastActivity = recognizerData.lastActivity;
        return lastActivity ? lastActivity : null;
    }
    async updateLastActivity(recognizer, activity) {
        const isActive = await this.isActive(recognizer);
        if (!isActive) {
            return null;
        }
        this.database.updateDocument(recognizer, { lastActivity: activity });
    }
    async updateStatus(recognizer, active, startOptions = {}) {
        const newData = {
            active,
            startOptions,
            lastActivity: null,
        };
        const prevData = await this.getRecognizerData(recognizer);
        if (!prevData) {
            this.database.createDocument(Object.assign({ docType: DOC_TYPE }, newData), recognizer);
            return;
        }
        this.database.updateDocument(recognizer, newData);
    }
    async getRecognizerData(recognizer) {
        const recognizerData = this.database.getDocument(recognizer);
        if (!recognizerData) {
            return null;
        }
        return recognizerData;
    }
}
export const recognizersStateStoreDb = new RecognizersStateStoreDb();
//# sourceMappingURL=store.js.map